aboutsummaryrefslogtreecommitdiffstats
path: root/test/vpp_interface.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/vpp_interface.py')
-rw-r--r--test/vpp_interface.py10
1 files changed, 7 insertions, 3 deletions
diff --git a/test/vpp_interface.py b/test/vpp_interface.py
index 29edb70e..9c904aac 100644
--- a/test/vpp_interface.py
+++ b/test/vpp_interface.py
@@ -226,12 +226,16 @@ class VppInterface(object):
self.has_ip6_config = False
self.has_ip6_config = False
- def configure_ipv6_neighbors(self):
- """For every remote host assign neighbor's MAC to IPv6 address."""
+ def configure_ipv6_neighbors(self, vrf_id=0):
+ """For every remote host assign neighbor's MAC to IPv6 addresses.
+
+ :param vrf_id: The FIB table / VRF ID. (Default value = 0)
+ """
for host in self._remote_hosts:
macn = host.mac.replace(":", "").decode('hex')
+ ipn = host.ip6n
self.test.vapi.ip_neighbor_add_del(
- self.sw_if_index, macn, host.ip6n, is_ipv6=1)
+ self.sw_if_index, macn, ipn, vrf_id, is_ipv6=1)
def unconfig(self):
"""Unconfigure IPv6 and IPv4 address on the VPP interface."""